native_animated_splash library

Classes

AndroidSplashGenerator
Generates Android splash screen assets and configurations based on provided settings.
IOSSplashGenerator
Generates iOS splash screen assets and configurations based on provided settings.
SplashConfig
Represents the configuration for a splash screen.
SplashConfigParser
Parses a YAML file to create a SplashConfig instance.